@@ -70,6 +70,13 @@ class SynDB(object):
         else:
             raise self.key_error
 
+    def ping(self):
+        try:
+            self._load()
+            return True
+        except:
+            return False
+
     def update(self, key, value):
         if key in self.db:
             self.db[key] = value
@@ -120,6 +127,8 @@ class SynDB(object):
         else:
             return False
 
+    ## Must read, All of the code under this line is being tested.
+
     def list_create(self, key):
         if not key in self.db:
             self.db[key] = []
@@ -133,5 +142,19 @@ class SynDB(object):
             self.db[key].append(value)
             self._autodump()
             return True
+        else:
+            return False
+
+    def list_get(self, key):
+        if key in self.db:
+            return self.db[key]
+        else:
+            return False
+
+    def list_delete(self, key, value):
+        if key in self.db:
+            self.db[key].remove(value)
+            self._autodump()
+            return True
         else:
             return False
\ No newline at end of file
